//+------------------------------------------------------------------+
//|                                                    DeltaSpot.mqh |
//|                               Copyright 2019, Vladimir Mikhailov |
//|                                                mikh.vl@gmail.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2019, Vladimir Mikhailov"
#property link      "mikh.vl@gmail.com"
#property version   "1.00"
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
class CDeltaSpot
  {
private:
   string            m_symbol_spot;
   string            m_symbol_fut;
   double            m_avr_sf;
   double            m_sum_sf;
   ulong             m_count;
   double            m_last_sp;
   double            m_p;
   
public:
   void              Reset(void);
   double            Count(void);
   double            GetAvr(void);
   double            GetLastSpot(void);
   void              Init(string symbol_fut, string symbol_spot);
   void              DeInit(void);
  };
//+------------------------------------------------------------------+
//|  Init                                                            |
//+------------------------------------------------------------------+
void CDeltaSpot::Init(string symbol_fut,string symbol_spot)
  {
   m_symbol_fut=symbol_fut;
   m_symbol_spot=symbol_spot;
   SymbolSelect(m_symbol_spot,true);
   m_p=pow(10,SymbolInfoInteger(m_symbol_spot,SYMBOL_DIGITS));
  }
//+------------------------------------------------------------------+
//|  DeInit                                                          |
//+------------------------------------------------------------------+
void CDeltaSpot::DeInit(void)
  {
//---
  }
//+------------------------------------------------------------------+
//|  Reset                                                           |
//+------------------------------------------------------------------+
void CDeltaSpot::Reset(void)
   {
    m_avr_sf=0;
    m_count=0;
    m_sum_sf=0;
   }
//+------------------------------------------------------------------+
//|  Count                                                           |
//+------------------------------------------------------------------+
double CDeltaSpot::Count(void)
   {
    double last[1];
    CopyClose(m_symbol_spot,PERIOD_CURRENT,0,1,last);
    m_count++;
    m_last_sp=last[0] * m_p;
    double points=fabs(SymbolInfoDouble(m_symbol_fut,SYMBOL_LAST)-m_last_sp);
    m_sum_sf+=points;
    return(points);
   }
//+------------------------------------------------------------------+
//|  GetAvr                                                          |
//+------------------------------------------------------------------+
double CDeltaSpot::GetAvr(void)
   {
    m_avr_sf=0;
    if(m_count>0)
      m_avr_sf=NormalizeDouble(m_sum_sf/m_count,(int)SymbolInfoInteger(m_symbol_fut,SYMBOL_DIGITS));
    return(m_avr_sf);
   }
//+------------------------------------------------------------------+
//|  GetLastSpot                                                     |
//+------------------------------------------------------------------+
double CDeltaSpot::GetLastSpot(void)
   {
    return(m_last_sp);
   }
//+------------------------------------------------------------------+
